WITH 
Totals(CategId, Amount) AS (
    SELECT  
        t.CategId, 
        Sum(t.TransAmount * CASE WHEN t.TransCode == 'Withdrawal' THEN -1 ELSE 1 END) AS Amount
    FROM CHECKINGACCOUNT_V1 t
    WHERE t.ToAccountId = -1 
    AND t.TransDate >= '&begin_date' AND t.TransDate <= '&end_date'
    GROUP BY t.CategId
), 
Categories(CategId, ParentId) AS (
    SELECT CategId, ParentId FROM CATEGORY_V1
    UNION ALL
    SELECT c.CategId, p.ParentId FROM CATEGORY_V1 c
    JOIN Categories p ON c.ParentId = p.CategId WHERE c.ParentId <> -1
), 
FlowAmounts(ParentId, CategId, Amount) AS (
    SELECT c.ParentId, c.CategId, (
        SELECT Sum(t.Amount) FROM Totals t
        WHERE t.CategId = c.CategId OR t.CategId IN (SELECT p.CategId FROM Categories p WHERE p.ParentId = c.CategId)
    ) AS Amount
    FROM CATEGORY_V1 c 
)

SELECT 
    CASE WHEN a.Amount > 0 THEN
        c2.CategName
    ELSE 
        COALESCE(c1.CATEGNAME, 'Budget')
    END AS Source,

    CASE WHEN a.Amount > 0 THEN
        COALESCE(c1.CATEGNAME, 'Budget')
    ELSE 
        c2.CategName
    END AS Target,

    Round(Abs(a.Amount), 2) AS Amount
FROM FlowAmounts a
LEFT JOIN CATEGORY_V1 c2 on a.CategId = c2.CategId
LEFT JOIN CATEGORY_V1 c1 on a.ParentId = c1.CategId
WHERE  a.Amount IS NOT NULL
